package local

import "os/exec"

func buildCmd(*exec.Cmd) error {
	return nil
}
